From ef23393d6bc354997d1f75219eb83beb97d38442 Mon Sep 17 00:00:00 2001
From: Shynur <one.last.kiss@outlook.com>
Date: Thu, 30 Mar 2023 01:29:17 +0800
Subject: [PATCH] scroll-conservatively is overriden by scroll-step

GNU Emacs Manual, 14.3 Automatic Scrolling:

> In case you customize multiple variables, the order of priority is: `scroll-conservatively`, then `scroll-step`, ...

It works for `next-line`, BUT ignores `previous-line`.

_____________________________________

Say evaluate the following Lisp code:

```
(setq scroll-conservatively 101)
(setq scroll-step 5)
```

Then, when calling `previous-line` which will lead to auto-scrolling,
it acts like that `scroll-conservatively` is not set,
i.e., Emacs will scroll 5 lines.

This PATCH fixes the BUG.
---
 src/xdisp.c | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/src/xdisp.c b/src/xdisp.c
index 754a7c16c76..76d6592bf00 100644
--- a/src/xdisp.c
+++ b/src/xdisp.c
@@ -18546,8 +18546,9 @@ try_scrolling (Lisp_Object window, bool just_this_one_p,
 	  start_display (&it, w, startp);
 
 	  if (arg_scroll_conservatively)
-	    amount_to_scroll = max (dy, frame_line_height
-				    * max (scroll_step, temp_scroll_step));
+	    amount_to_scroll
+	      = min (max (dy, frame_line_height),
+		     frame_line_height * arg_scroll_conservatively);
 	  else if (scroll_step || temp_scroll_step)
 	    amount_to_scroll = scroll_max;
 	  else
-- 
2.34.1

